Discover Packages
github.com/Geogboe/rog
internal
logger
package
Version:
v0.5.0
Opens a new window with list of versions in this module.
Published: Mar 31, 2026
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
func Debug(format string , args ...interface{})
Debug logs a debug message
func Error(format string , args ...interface{})
Error logs an error message
func Info(format string , args ...interface{})
Info logs an info message
Init initializes the logger with the specified level
InitFromEnv initializes the logger from environment variables
ROG_VERBOSE: if set to "true" or "1", enables verbose logging
ROG_DEBUG: if set to "true" or "1", enables debug logging (overrides verbose)
SetLevel sets the current log level
func Verbose(format string , args ...interface{})
Verbose logs a verbose message
LogLevel represents logging verbosity
const (
LevelSilent LogLevel = iota
LevelError
LevelInfo
LevelVerbose
LevelDebug
)
GetLevel returns the current log level
Source Files
¶
Click to show internal directories.
Click to hide internal directories.